{ config, libs, pkgs, ... }:

{
  imports = [
    ./app-bureautique.nix
    ./app-cao.nix
    ./app-client-internet.nix
    ./app-dev.nix
    ./app-multimedia.nix
    ./app-network.nix
  ];

  environment.systemPackages = with pkgs; [
    cowsay
    curlftpfs
    docker
    espeak
    gnome3.seahorse
    gnuplot
    gparted
    gpm
    inotify-tools
    iotop
    jekyll
    josm
    linuxPackages.virtualbox
    linuxPackages.virtualboxGuestAdditions
    lm_sensors
    lshw
    lsof
    lz4
    lzop
    nfs-utils
    ntfs3g
    ntp
    pass
    pgadmin
    postfix
    powerline-fonts
    powertop
    pwgen
    python27Packages.docker_compose
    python27Packages.ansible2
    python27Packages.glances
    sakura
    samba
    slock
    spaceFM
    sqlitebrowser
    sshfsFuse
    taskwarrior
    transmission_gtk
    transmission_remote_gtk
    udevil
    unbound
    unetbootin
    urbanterror
    usbutils
    vbindiff
    vifm
    viking
    wmname
    yubikey-personalization-gui
  ];

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override { enablePluginFancy = true; };
    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  # Enable the X11 windowing system.
  services.xserver = {
    enable = true;
    layout = "fr";
    xkbOptions = "eurosign:e";
    displayManager.lightdm.enable = true;
    windowManager.awesome.enable = true;
    startGnuPGAgent = true;
    startOpenSSHAgent = false; # pas compatible avec l'agent GnuPG
    inputClassSections = [''
    Identifier  "Marble Mouse"
    MatchProduct "Logitech USB Trackball"
    MatchIsPointer "on"
    MatchDevicePath "/dev/input/event*"
    Driver "evdev"
    # Physical button #s:     A b D - - - - B C    b = A & D simultaneously;   - = no button
    #Option "ButtonMapping" "1 8 3 4 5 6 7 2 2"   #  For right-hand placement
    #Option "ButtonMapping" "3 8 1 4 5 6 7 2 2"   #  For left-hand placement

    # EmulateWheel refers to emulating a mouse wheel using Marble Mouse trackball.
    Option "EmulateWheel" "true"
    Option "EmulateWheelButton" "8"   # Factory default; use "9" for left-side placement.

    # EmulateWheelInertia specifies how far (in pixels) the pointer must move to
    # generate button press/release events in wheel emulation mode.
    Option "EmulateWheelInertia" "10" # Factory default: 50

    Option "ZAxisMapping" "4 5"
    Option "XAxisMapping" "6 7"       # Disable this for vertical-only scrolling.
    # Emulate3Buttons refers to the act of pressing buttons A and D
    # simultaneously to emulate a middle-click or wheel click.
    Option "Emulate3Buttons" "true"   # Factory default.
    ''];
  };

  hardware.pulseaudio = {
    enable = true;
    support32Bit = true;
  };
  environment.etc."pulse/daemon.conf".text = "flat-volumes = no";
  nixpkgs.config.allowUnfree = true;
}
